@@ -1,17 +1,14 @@
-# coding: utf-8
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 """A lab app that runs a sub process for a demo or a test."""
 import sys
 
-from tornado.ioloop import IOLoop
-from traitlets import Bool
-
-from .server import ServerApp
-from .handlers import add_handlers, LabConfig
-from .process import Process
-
-from traitlets import Unicode
-
 from jupyter_server.extension.application import ExtensionApp, ExtensionAppJinjaMixin
+from tornado.ioloop import IOLoop
+
+from .handlers import LabConfig, add_handlers
+from .process import Process
 
 
 class ProcessApp(ExtensionAppJinjaMixin, LabConfig, ExtensionApp):
@@ -26,19 +23,19 @@ class ProcessApp(ExtensionAppJinjaMixin, LabConfig, ExtensionApp):
         """Get the command and kwargs to run with `Process`.
         This is intended to be overridden.
         """
-        return ['python', '--version'], dict()
+        return [sys.executable, "--version"], {}
 
     def initialize_settings(self):
-        """Start the application.
-        """
+        """Start the application."""
         IOLoop.current().add_callback(self._run_command)
 
     def initialize_handlers(self):
+        """Initialize the handlers."""
         add_handlers(self.handlers, self)
 
     def _run_command(self):
         command, kwargs = self.get_command()
-        kwargs.setdefault('logger', self.log)
+        kwargs.setdefault("logger", self.log)
         future = Process(command, **kwargs).wait_async()
         IOLoop.current().add_future(future, self._process_finished)
 
