@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 """A workspace management CLI"""
 import json
 import sys
@@ -17,6 +20,8 @@ DEFAULT_WORKSPACE = "default"
 
 
 class WorkspaceListApp(JupyterApp, LabConfig):
+    """An app to list workspaces."""
+
     version = __version__
     description = """
     Print all the workspaces available
@@ -54,22 +59,26 @@ class WorkspaceListApp(JupyterApp, LabConfig):
     )
 
     def initialize(self, *args, **kwargs):
+        """Initialize the app."""
         super().initialize(*args, **kwargs)
         self.manager = WorkspacesManager(self.workspaces_dir)
 
     def start(self):
+        """Start the app."""
         workspaces = self.manager.list_workspaces()
         if self.jsonlines:
             for workspace in workspaces:
-                print(json.dumps(workspace))
+                print(json.dumps(workspace))  # noqa
         elif self.json:
-            print(json.dumps(workspaces))
+            print(json.dumps(workspaces))  # noqa
         else:
             for workspace in workspaces:
-                print(workspace["metadata"]["id"])
+                print(workspace["metadata"]["id"])  # noqa
 
 
 class WorkspaceExportApp(JupyterApp, LabConfig):
+    """A workspace export app."""
+
     version = __version__
     description = """
     Export a JupyterLab workspace
@@ -81,10 +90,12 @@ class WorkspaceExportApp(JupyterApp, LabConfig):
     """
 
     def initialize(self, *args, **kwargs):
+        """Initialize the app."""
         super().initialize(*args, **kwargs)
         self.manager = WorkspacesManager(self.workspaces_dir)
 
     def start(self):
+        """Start the app."""
         if len(self.extra_args) > 1:  # pragma: no cover
             warnings.warn("Too many arguments were provided for workspace export.")
             self.exit(1)
@@ -92,12 +103,14 @@ class WorkspaceExportApp(JupyterApp, LabConfig):
         raw = DEFAULT_WORKSPACE if not self.extra_args else self.extra_args[0]
         try:
             workspace = self.manager.load(raw)
-            print(json.dumps(workspace))
+            print(json.dumps(workspace))  # noqa
         except Exception:  # pragma: no cover
-            print(json.dumps(dict(data=dict(), metadata=dict(id=raw))))
+            self.log.error(json.dumps(dict(data=dict(), metadata=dict(id=raw))))
 
 
 class WorkspaceImportApp(JupyterApp, LabConfig):
+    """A workspace import app."""
+
     version = __version__
     description = """
     Import a JupyterLab workspace
@@ -119,29 +132,30 @@ class WorkspaceImportApp(JupyterApp, LabConfig):
     aliases = {"name": "WorkspaceImportApp.workspace_name"}
 
     def initialize(self, *args, **kwargs):
+        """Initialize the app."""
         super().initialize(*args, **kwargs)
         self.manager = WorkspacesManager(self.workspaces_dir)
 
     def start(self):
-
+        """Start the app."""
         if len(self.extra_args) != 1:  # pragma: no cover
-            print("One argument is required for workspace import.")
+            self.log.info("One argument is required for workspace import.")
             self.exit(1)
 
         with self._smart_open() as fid:
             try:  # to load, parse, and validate the workspace file.
                 workspace = self._validate(fid)
             except Exception as e:  # pragma: no cover
-                print(f"{fid.name} is not a valid workspace:\n{e}")
+                self.log.info(f"{fid.name} is not a valid workspace:\n{e}")
                 self.exit(1)
 
         try:
             workspace_path = self.manager.save(workspace["metadata"]["id"], json.dumps(workspace))
         except Exception as e:  # pragma: no cover
-            print(f"Workspace could not be exported:\n{e!s}")
+            self.log.info(f"Workspace could not be exported:\n{e!s}")
             self.exit(1)
 
-        print(f"Saved workspace: {workspace_path!s}")
+        self.log.info(f"Saved workspace: {workspace_path!s}")
 
     def _smart_open(self):
         file_name = self.extra_args[0]
@@ -152,7 +166,7 @@ class WorkspaceImportApp(JupyterApp, LabConfig):
             file_path = Path(file_name).resolve()
 
             if not file_path.exists():  # pragma: no cover
-                print(f"{file_name!s} does not exist.")
+                self.log.info(f"{file_name!s} does not exist.")
                 self.exit(1)
 
             return file_path.open(encoding="utf-8")
